@@ -66,11 +66,11 @@ void quick_svd(double *E, double *U, double *S, double *VT) {
 	matrix_cross(v_b, v_c, v_a);
     }
 
-    matrix_product(3, 3, 3, 1, E, v_a, tmp);
+    matrix_product331(E, v_a, tmp);
     mag = matrix_norm(3, 1, tmp);
     matrix_scale(3, 1, tmp, 1.0 / mag, u_a);
 
-    matrix_product(3, 3, 3, 1, E, v_b, tmp);
+    matrix_product331(E, v_b, tmp);
     mag = matrix_norm(3, 1, tmp);
     matrix_scale(3, 1, tmp, 1.0 / mag, u_b);
 
@@ -83,7 +83,7 @@ v2_t project(double *R, double *t0, double *P) {
     v2_t result;
 
     /* Rigid transform */
-    matrix_product(3, 3, 3, 1, R, P, tmp);
+    matrix_product331(R, P, tmp);
     matrix_sum(3, 1, 3, 1, tmp, t0, tmp2);
     
     /* Perspective division */
@@ -155,7 +155,7 @@ v3_t triangulate_n_refine(v3_t pt, int num_points,
 	double pp[3];
 
 	/* Compute projection error */
-	matrix_product(3, 3, 3, 1, R + Roff, x, pp);
+	matrix_product331(R + Roff, x, pp);
 	pp[0] += t[toff + 0];
 	pp[1] += t[toff + 1];
 	pp[2] += t[toff + 2];
@@ -220,7 +220,7 @@ v3_t triangulate_n(int num_points,
 	double pp[3];
 
 	/* Compute projection error */
-	matrix_product(3, 3, 3, 1, R + Roff, x, pp);
+	matrix_product331(R + Roff, x, pp);
 	pp[0] += t[toff + 0];
 	pp[1] += t[toff + 1];
 	pp[2] += t[toff + 2];
@@ -248,7 +248,7 @@ v3_t triangulate_n(int num_points,
 	double pp[3];
 
 	/* Compute projection error */
-	matrix_product(3, 3, 3, 1, R + Roff, x, pp);
+	matrix_product331(R + Roff, x, pp);
 	pp[0] += t[toff + 0];
 	pp[1] += t[toff + 1];
 	pp[2] += t[toff + 2];
@@ -322,12 +322,12 @@ v3_t triangulate(v2_t p, v2_t q,
 	double pp[3], qp[3];
 
 	/* Compute projection error */
-	matrix_product(3, 3, 3, 1, R0, x, pp);
+	matrix_product331(R0, x, pp);
 	pp[0] += t0[0];
 	pp[1] += t0[1];
 	pp[2] += t0[2];
 		
-	matrix_product(3, 3, 3, 1, R1, x, qp);
+	matrix_product331(R1, x, qp);
 	qp[0] += t1[0];
 	qp[1] += t1[1];
 	qp[2] += t1[2];	
@@ -354,7 +354,7 @@ void find_extrinsics(double *F, double *K1, double *K2,
     matrix_invert(3, K1, K1_inv);
     matrix_invert(3, K2, K2_inv);
     
-    matrix_product(3, 3, 3, 3, F, K1, tmp);
+    matrix_product33(F, K1, tmp);
     matrix_transpose_product(3, 3, 3, 3, K2, tmp, E);
 
     find_extrinsics_essential(E, p1, p2, R, t);
@@ -401,11 +401,11 @@ int find_extrinsics_essential(double *E, v2_t p1, v2_t p2,
     /* Now find R and t */
     tu[0] = U[2];  tu[1] = U[5];  tu[2] = U[8];
 
-    matrix_product(3, 3, 3, 3, U, D, tmp);
-    matrix_product(3, 3, 3, 3, tmp, VT, Ra);
-    matrix_product(3, 3, 3, 3, U, DT, tmp);
+    matrix_product33(U, D, tmp);
+    matrix_product33(tmp, VT, Ra);
+    matrix_product33(U, DT, tmp);
 
-    matrix_product(3, 3, 3, 3, tmp, VT, Rb);
+    matrix_product33(tmp, VT, Rb);
 
     if (matrix_determinant3(Ra) < 0.0) {
 	// printf("flipping...\n");
@@ -422,7 +422,7 @@ int find_extrinsics_essential(double *E, v2_t p1, v2_t p2,
 
     Q = triangulate(p1, p2, I, t0, Ra, tu, &error);
     Qv[0] = Vx(Q), Qv[1] = Vy(Q), Qv[2] = Vz(Q);
-    matrix_product(3, 3, 3, 1, Ra, Qv, tmp);
+    matrix_product331(Ra, Qv, tmp);
     matrix_sum(3, 1, 3, 1, tmp, tu, tmp2);
     PQ = v3_new(tmp2[0], tmp2[1], tmp2[2]);
 
@@ -445,7 +445,7 @@ int find_extrinsics_essential(double *E, v2_t p1, v2_t p2,
         /* Triangulate again */
         Q = triangulate(p1, p2, I, t0, Rb, tu, &error);
         Qv[0] = Vx(Q), Qv[1] = Vy(Q), Qv[2] = Vz(Q);
-        matrix_product(3, 3, 3, 1, Rb, Qv, tmp);
+        matrix_product331(Rb, Qv, tmp);
         matrix_sum(3, 1, 3, 1, tmp, tu, tmp2);
         PQ = v3_new(tmp2[0], tmp2[1], tmp2[2]);
 
@@ -470,7 +470,7 @@ int find_extrinsics_essential(double *E, v2_t p1, v2_t p2,
         }
     }
 
-    matrix_product(3, 3, 3, 1, R, Q.p, tmp2);
+    matrix_product331(R, Q.p, tmp2);
     matrix_sum(3, 1, 3, 1, tmp2, t, tmp2);
 
     printf("[find_extrinsics] error: %0.3e\n", error);
@@ -527,11 +527,11 @@ int find_extrinsics_essential_multipt(double *E, int n,
     /* Now find R and t */
     tu[0] = U[2];  tu[1] = U[5];  tu[2] = U[8];
 
-    matrix_product(3, 3, 3, 3, U, D, tmp);
-    matrix_product(3, 3, 3, 3, tmp, VT, Ra);
-    matrix_product(3, 3, 3, 3, U, DT, tmp);
+    matrix_product33(U, D, tmp);
+    matrix_product33(tmp, VT, Ra);
+    matrix_product33(U, DT, tmp);
 
-    matrix_product(3, 3, 3, 3, tmp, VT, Rb);
+    matrix_product33(tmp, VT, Rb);
 
     if (matrix_determinant3(Ra) < 0.0) {
 	// printf("flipping...\n");
@@ -549,7 +549,7 @@ int find_extrinsics_essential_multipt(double *E, int n,
     for (i = 0; i < n; i++) {
         Q = triangulate(p1[i], p2[i], I, t0, Ra, tu, &error);
         Qv[0] = Vx(Q), Qv[1] = Vy(Q), Qv[2] = Vz(Q);
-        matrix_product(3, 3, 3, 1, Ra, Qv, tmp);
+        matrix_product331(Ra, Qv, tmp);
         matrix_sum(3, 1, 3, 1, tmp, tu, tmp2);
         PQ = v3_new(tmp2[0], tmp2[1], tmp2[2]);
 
@@ -588,7 +588,7 @@ int find_extrinsics_essential_multipt(double *E, int n,
         for (i = 0; i < n; i++) {
             Q = triangulate(p1[i], p2[i], I, t0, Rb, tu, &error);
             Qv[0] = Vx(Q), Qv[1] = Vy(Q), Qv[2] = Vz(Q);
-            matrix_product(3, 3, 3, 1, Rb, Qv, tmp);
+            matrix_product331(Rb, Qv, tmp);
             matrix_sum(3, 1, 3, 1, tmp, tu, tmp2);
             PQ = v3_new(tmp2[0], tmp2[1], tmp2[2]);
 
@@ -683,7 +683,7 @@ static v3_t *condition_points_3D(int num_points, v3_t *pts, double *T) {
     factor = sqrt(3.0) / avg_dist;
 
     matrix_transpose_product2(4, 4, 4, 4, Sinv, U16, action);
-    matrix_product(4, 4, 4, 4, action, Ttrans, T);
+    matrix_product44(action, Ttrans, T);
 
     for (i = 0; i < num_points; i++) {
 	double x = factor * (Vx(pts[i]) - Vx(mean));
@@ -693,7 +693,7 @@ static v3_t *condition_points_3D(int num_points, v3_t *pts, double *T) {
 	double pt[4] = { Vx(pts[i]), Vy(pts[i]), Vz(pts[i]), 1.0 };
 	double Tpt[4];
 	
-	matrix_product(4, 4, 4, 1, T, pt, Tpt);
+	matrix_product441(T, pt, Tpt);
 	
 	pts_new[i] = v3_new(Tpt[0], Tpt[1], Tpt[2]);
     }
@@ -828,7 +828,7 @@ int find_projection_3x4(int num_pts, v3_t *points, v2_t *projs, double *P) {
 	    double pr[3];
 	    double dx, dy, dist;
 
-	    matrix_product(3, 4, 4, 1, P, pt, pr);
+	    matrix_product341(P, pt, pr);
             // EDIT!!!
 	    pr[0] /= -pr[2];
 	    pr[1] /= -pr[2];
@@ -877,7 +877,7 @@ static void projection_residual(const int *m, const int *n, double *x,
 	double pr[3];
 	double dx, dy;
 	
-	matrix_product(3, 4, 4, 1, P, pt, pr);
+	matrix_product341(P, pt, pr);
         // EDIT!!
 	pr[0] /= -pr[2];
 	pr[1] /= -pr[2];
@@ -1021,7 +1021,7 @@ int find_projection_3x4_ransac(int num_pts, v3_t *points, v2_t *projs,
 		double pr[3];
 		double dx, dy, dist;
 
-		matrix_product(3, 4, 4, 1, Ptmp, pt, pr);
+		matrix_product341(Ptmp, pt, pr);
 
 		/* Check cheirality */
                 // EDIT!!!
@@ -1093,7 +1093,7 @@ int find_projection_3x4_ransac(int num_pts, v3_t *points, v2_t *projs,
 	    double pr[3];
 	    double dx, dy, dist;
 	    
-	    matrix_product(3, 4, 4, 1, Pbest, pt, pr);
+	    matrix_product341(Pbest, pt, pr);
 
 	    /* Check cheirality */
             // EDIT!!!
@@ -1150,7 +1150,7 @@ int find_projection_3x4_ransac(int num_pts, v3_t *points, v2_t *projs,
 	    double pr[3];
 	    double dx, dy, dist;
 	    
-	    matrix_product(3, 4, 4, 1, Plinear, pt, pr);
+	    matrix_product341(Plinear, pt, pr);
 
             // EDIT!!!
 	    if (sign * pr[2] > 0.0)
@@ -1185,7 +1185,7 @@ int find_projection_3x4_ransac(int num_pts, v3_t *points, v2_t *projs,
 	    double pr[3];
 	    double dx, dy, dist;
 	    
-	    matrix_product(3, 4, 4, 1, Plinear, pt, pr);
+	    matrix_product341(Plinear, pt, pr);
 	    pr[0] /= pr[2];
 	    pr[1] /= pr[2];
 	    
@@ -1234,7 +1234,7 @@ int find_projection_3x4_ransac(int num_pts, v3_t *points, v2_t *projs,
 		double pr[3];
 		double dx, dy, dist;
 	    
-		matrix_product(3, 4, 4, 1, P, pt, pr);
+		matrix_product341(P, pt, pr);
 
                 // EDIT!!!
 		if (sign * pr[2] > 0.0)
@@ -1274,7 +1274,7 @@ int find_projection_3x4_ransac(int num_pts, v3_t *points, v2_t *projs,
 	    double pr[3];
 	    double dx, dy, dist;
 	    
-	    matrix_product(3, 4, 4, 1, P, pt, pr);
+	    matrix_product341(P, pt, pr);
 
             // EDIT!!!
 	    pr[0] /= -pr[2];
