@@ -75,7 +75,7 @@ void matrix_transpose(int m, int n, double *A, double *AT) {
             AT[j * m + i] = A[i * n + j];
 }
 
-#if 0
+#if !defined(WIN32) && !defined(__NO_MKL__)
 void matrix_product_ipp(int Am, int An, int Bn, 
                         const double *A, const double *B, double *R) 
 {
@@ -256,6 +256,13 @@ void matrix_product331(double *A, double *b, double *r)
     r[2] = A[6] * b[0] + A[7] * b[1] + A[8] * b[2];
 }
 
+void matrix_product341(double *A, double *b, double *r)
+{
+    r[0] = A[0] * b[0] + A[1] * b[1] + A[2] * b[2] + A[3] * b[3];
+    r[1] = A[4] * b[0] + A[5] * b[1] + A[6] * b[2] + A[7] * b[3];
+    r[2] = A[8] * b[0] + A[9] * b[1] + A[10] * b[2] + A[11] * b[3];
+}
+
 void matrix_product441(double *A, double *b, double *r)
 {
     r[0] = A[0] * b[0] + A[1] * b[1] + A[2] * b[2] + A[3] * b[3];
@@ -1552,7 +1559,7 @@ void axis_angle_to_matrix(double *axis, double angle, double *R) {
     s = sin(angle);
 
     matrix_ident(3, ident);
-    matrix_product(3, 3, 3, 3, n, n, nsq);
+    matrix_product33(n, n, nsq);
     matrix_scale(3, 3, n, s, sn);
     matrix_scale(3, 3, nsq, (1 - c), cnsq);
 
@@ -1575,7 +1582,7 @@ void axis_angle_to_matrix4(double *axis, double angle, double *R) {
     s = sin(angle);
 
     matrix_ident(3, ident);
-    matrix_product(3, 3, 3, 3, n, n, nsq);
+    matrix_product33(n, n, nsq);
     matrix_scale(3, 3, n, s, sn);
     matrix_scale(3, 3, nsq, (1 - c), cnsq);
 
