@@ -36,7 +36,10 @@
 
 #include "Geometry.h"
 #include "Camera.h"
-// #include "UtilGL.h"
+
+#ifndef __BUNDLER__
+#include "UtilGL.h"
+#endif /* __BUNDLER__ */
 
 #include "defines.h"
 #include "matrix.h"
